@@ -31,7 +31,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: data.c 2160 2013-06-06 21:20:59Z beerli $
+$Id: data.c 2169 2013-08-24 19:02:04Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -2222,7 +2222,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
   MYREAL *avghet;
   MYREAL v;
   MYREAL avghet1;
-  MYREAL avghetall = 0.0;
+  //MYREAL avghetall = 0.0;
   long *maxalleles;
   long *maxallelepop;
   MYREAL ***freq;
@@ -2232,7 +2232,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
   MYREAL general_homo;
   FILE *outfile = world->outfile;
   long loctotal;
-  long t;
+  //long t;
   boolean second = (strchr(ALLELETYPES,options->datatype)!=NULL);
   if (strchr (DNASEQUENCETYPES, options->datatype))
     return; /*we do not calculate allele frequencies for DNA sequences*/
