@@ -33,12 +33,12 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 
-$Id: definitions.h 2160 2013-06-06 21:20:59Z beerli $
+$Id: definitions.h 2169 2013-08-24 19:02:04Z beerli $
  
 *----------------------------------------------------------------
 */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.5.4"
+#define MIGRATEVERSION "3.6.1"
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
@@ -82,7 +82,7 @@ $Id: definitions.h 2160 2013-06-06 21:20:59Z beerli $
 
 /* random number system */
 #define LCG
-#ifdef MERSENNETWISTER
+#ifdef MERSENNE_TWISTER
 #undef LCG
 #endif
 #ifdef SPRNG
