@@ -12,15 +12,35 @@
  beerli@fsu.edu
  updated 2009
 
-Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2009 Peter Beerli, Tallahassee FL
+(c) 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
+(c) 2003-2009 Peter Beerli, Tallahassee FL
  
-$Id: tree.h 1729 2010-10-19 13:43:02Z beerli $
+ Permission is hereby granted, free of charge, to any person obtaining
+ a copy of this software and associated documentation files (the
+ "Software"), to deal in the Software without restriction, including
+ without limitation the rights to use, copy, modify, merge, publish,
+ distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject
+ to the following conditions:
+ 
+ The above copyright notice and this permission notice shall be
+ included in all copies or substantial portions of the Software.
+ 
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
+ ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ 
+$Id: tree.h 2157 2013-04-16 22:27:40Z beerli $
 -------------------------------------------------------*/
 #include "migration.h"
 void buildtree (world_fmt * world, option_fmt * options, data_fmt * data, long locus);
 void create_treetimelist (world_fmt * world, timelist_fmt ** ltl, long locus);
-void allocate_lineages (timelist_fmt **timevector,  long offset, long numpop);
+void allocate_lineages (timelist_fmt **timevector, const long offset, const long numpop);
 void allocate_tip (world_fmt * world, option_fmt * options, node ** p, long pop, long locus, long a, long ind, char **tipnames);
 void fix_times (world_fmt * world, option_fmt * options);
 void first_smooth (world_fmt * world, long locus);
